/**
 * IgaLib -> String
 * Copyright (C) 2001  Tosiki IGA , IgaLib project member
 *   (http://homepage2.nifty.com/igat/igapyon/index.html)
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jp.ne.nifty.iga.tosiki.string;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import java.io.*;
import java.util.*;

/**
 * [eBeBNXQeXgNXłB
 * JUnit𗘗păeXg{邽߂ɑ݂NXłB<BR>
 * ̃NXg̗prɗp邱Ƃ͖ł傤B
 *
 * @author Tosiki IGA
 */
public class MojiUtilTest
	extends TestCase
{
	public MojiUtilTest(String name)
	{
		super(name);
	}

	public static final void main(String[] args)
	{
		junit.textui.TestRunner.run(MojiUtilTest.class);
	}

	public void testFitRight()
	{
		assertEquals("ABCZZ",MojiUtil.fitRight("ABC",5,'Z'));
		assertEquals("ABCDE",MojiUtil.fitRight("ABCDEFG",5,'Z'));

		assertEquals("Z",MojiUtil.fitRight("",5,'Z'));
		assertEquals("Z",MojiUtil.fitRight("",5,'Z'));

		assertEquals(" ",MojiUtil.fitRight("",5,''));
		assertEquals(" ",MojiUtil.fitRight("",5,''));
		assertEquals(" ",MojiUtil.fitRight("",5,''));
	}

	public void testPadRight()
	{
		assertEquals("ABCZZ",MojiUtil.padRight("ABC",5,'Z'));
		assertEquals("ABCDEFG",MojiUtil.padRight("ABCDEFG",5,'Z'));

		assertEquals("Z",MojiUtil.padRight("",5,'Z'));
		assertEquals("",MojiUtil.padRight("",5,'Z'));

		assertEquals(" ",MojiUtil.padRight("",5,''));
		assertEquals(" ",MojiUtil.padRight("",5,''));
		assertEquals("",MojiUtil.padRight("",5,''));
	}

	public void testPadLeft()
	{
		assertEquals("ZZABC",MojiUtil.padLeft("ABC",5,'Z'));
		assertEquals("ABCDEFG",MojiUtil.padLeft("ABCDEFG",5,'Z'));

		assertEquals("Z",MojiUtil.padLeft("",5,'Z'));
		assertEquals("",MojiUtil.padLeft("",5,'Z'));

		assertEquals(" ",MojiUtil.padLeft("",5,''));
		assertEquals(" ",MojiUtil.padLeft("",5,''));
		assertEquals("",MojiUtil.padLeft("",5,''));
	}

	public void testTrimRight()
	{
		assertEquals("ABC",MojiUtil.trimRight("ABC"));
		assertEquals("ABC",MojiUtil.trimRight("ABC  "));
		assertEquals("AB C",MojiUtil.trimRight("AB C  "));
		assertEquals("A@B C",MojiUtil.trimRight("A@B C  "));

		assertEquals("",MojiUtil.trimRight(""));
		assertEquals(" ",MojiUtil.trimRight("  "));
		assertEquals(" ",MojiUtil.trimRight(" @"));
		assertEquals("@ ",MojiUtil.trimRight("@ @"));
	}

	public void testTrimLeft()
	{
		assertEquals("ABC",MojiUtil.trimLeft("ABC"));
		assertEquals("ABC  ",MojiUtil.trimLeft("  ABC  "));
		assertEquals("AB C  ",MojiUtil.trimLeft(" AB C  "));
		assertEquals("A@B C",MojiUtil.trimLeft(" A@B C"));

		assertEquals("",MojiUtil.trimLeft(""));
		assertEquals(" ",MojiUtil.trimLeft("  "));
		assertEquals(" @",MojiUtil.trimLeft("@ @"));
		assertEquals(" ",MojiUtil.trimLeft("@  "));
	}

	public void testSubString()
	{
		assertEquals("ABC",MojiUtil.subString("ABCDE",0,3));
		assertEquals("CD",MojiUtil.subString("ABCDE",2,2));
		assertEquals("CDE",MojiUtil.subString("ABCDE",2,6));

		assertEquals(" ",MojiUtil.subString("",0,5));
		assertEquals("",MojiUtil.subString("",0,6));
		assertEquals(" ",MojiUtil.subString("",0,7));
		assertEquals("",MojiUtil.subString("",0,8));
		assertEquals(" ",MojiUtil.subString("",0,9));
		assertEquals("",MojiUtil.subString("",0,10));
		assertEquals("",MojiUtil.subString("",0,11));

		assertEquals("",MojiUtil.subString("",2,4));

		assertEquals(" ",MojiUtil.subString("",1,5));
		assertEquals("  ",MojiUtil.subString("",1,6));
		assertEquals(" ",MojiUtil.subString("",1,7));
		assertEquals("  ",MojiUtil.subString("",1,8));
		assertEquals(" ",MojiUtil.subString("",1,9));
		assertEquals(" ",MojiUtil.subString("",1,10));
		assertEquals(" ",MojiUtil.subString("",1,11));
	}

	public void testToInteger()
	{
		assertEquals(
			362
			,MojiUtil.toInteger("362"));
		assertEquals(
			362
			,MojiUtil.toInteger("RUQ"));
		assertEquals(
			0
			,MojiUtil.toInteger(""));
		assertEquals(
			0
			,MojiUtil.toInteger(null));
		assertEquals(
			0
			,MojiUtil.toInteger("ł͂Ȃ"));
	}

	public void testToDate()
	{
		Calendar calendarTest=Calendar.getInstance();
		calendarTest.set(Calendar.YEAR,2001);
		calendarTest.set(Calendar.MONTH,12-1);
		calendarTest.set(Calendar.DATE,31);
		calendarTest=MojiUtil.trimTime(calendarTest);

		assertEquals(calendarTest.getTime(),MojiUtil.toDate("2001.12.31"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("2001/12/31"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("011231"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("20011231"));

		calendarTest.set(Calendar.HOUR_OF_DAY,14);
		calendarTest.set(Calendar.MINUTE,30);
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("2001/12/31 14:30"));

		calendarTest.set(Calendar.SECOND,52);
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("2001/12/31 14:30:52"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("2001.12.31 14:30:52"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("20011231 143052"));

		assertEquals(calendarTest.getTime(),MojiUtil.toDate("QOOPDPQDRP@PSFROFTQ"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("QOOPNPQRP@PSROTQb"));
		assertEquals(calendarTest.getTime(),MojiUtil.toDate("QOOPPQRP@PSROTQ"));
	}

	public void testReplace()
	{
		assertEquals("ABXYFG",MojiUtil.replace("ABCDEFG","CDE","XY"));
		assertEquals("ABCDEFG",MojiUtil.replace("ABCDEFG","VW","XYZ"));
		assertEquals("",MojiUtil.replace("","",""));
		assertEquals("",MojiUtil.replace("","",""));

		assertEquals("ABCDEFG",MojiUtil.replace("ABCDEFG","FGH","XYZ"));

		assertEquals("ABXYFGABXYFG",MojiUtil.replace("ABCDEFGABCDEFG","CDE","XY"));
	}
}


