/**
 * IgaLib -> String
 * Copyright (C) 2001  Tosiki IGA , IgaLib project member
 *   (http://homepage2.nifty.com/igat/igapyon/index.html)
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jp.ne.nifty.iga.tosiki.string;

import java.io.*;

/**
 * Spϊŗpϊe[ułB<BR>
 *
 * yQlz
 *   Tips for E-Mail
 *     http://www.ed.kanazawa-u.ac.jp/~iwasaki/Tips/tips.html#ASCII
 *
 * @author Tosiki IGA
 */
public class ZenkakuTable
{
	/**
	 * ASCII (ISO646) + SPACE
	 * 94 + 1
	 */
	public static final char tableAnk[][]={
		{' ','@'},
		{'!','I'},
		{'\"','h'},
		{'#',''},
		{'$',''},
		{'%',''},
		{'&',''},
		{'\'','f'},
		{'(','i'},
		{')','j'},
		{'*',''},
		{'+','{'},
		{',','C'},
		{'-','|'},
		{'.','D'},
		{'/','^'},
		{'0','O'},
		{'1','P'},
		{'2','Q'},
		{'3','R'},
		{'4','S'},
		{'5','T'},
		{'6','U'},
		{'7','V'},
		{'8','W'},
		{'9','X'},
		{':','F'},
		{';','G'},
		{'<',''},
		{'=',''},
		{'>',''},
		{'?','H'},
		{'@',''},
		{'A','`'},
		{'B','a'},
		{'C','b'},
		{'D','c'},
		{'E','d'},
		{'F','e'},
		{'G','f'},
		{'H','g'},
		{'I','h'},
		{'J','i'},
		{'K','j'},
		{'L','k'},
		{'M','l'},
		{'N','m'},
		{'O','n'},
		{'P','o'},
		{'Q','p'},
		{'R','q'},
		{'S','r'},
		{'T','s'},
		{'U','t'},
		{'V','u'},
		{'W','v'},
		{'X','w'},
		{'Y','x'},
		{'Z','y'},
		{'[','m'},
		{'\\',''}, // _(US-ASCII) (JIS[})
		{']','n'},
		{'^','O'},
		{'_','Q'},
		{'`','M'},
		{'a',''},
		{'b',''},
		{'c',''},
		{'d',''},
		{'e',''},
		{'f',''},
		{'g',''},
		{'h',''},
		{'i',''},
		{'j',''},
		{'k',''},
		{'l',''},
		{'m',''},
		{'n',''},
		{'o',''},
		{'p',''},
		{'q',''},
		{'r',''},
		{'s',''},
		{'t',''},
		{'u',''},
		{'v',''},
		{'w',''},
		{'x',''},
		{'y',''},
		{'z',''},
		{'{','o'},
		{'|','b'},
		{'}','p'},
		{'~','`'}, // `(US-ASCII) P(JIS[})
	};

	public static final char tableKatakana[][]={
		{'','E'},
		{'','B'},
		{'','u'},
		{'','v'},
		{'','A'},
		{'','E'},
		{'',''},
		{'','@'},
		{'','B'},
		{'','D'},
		{'','F'},
		{'','H'},
		{'',''},
		{'',''},
		{'',''},
		{'','b'},
		{'','['},
		{'','A'},
		{'','C'},
		{'','E'},
		{'','G'},
		{'','I'},
		{'','J'},
		{'','L'},
		{'','N'},
		{'','P'},
		{'','R'},
		{'','T'},
		{'','V'},
		{'','X'},
		{'','Z'},
		{'','\'},
		{'','^'},
		{'','`'},
		{'','c'},
		{'','e'},
		{'','g'},
		{'','i'},
		{'','j'},
		{'','k'},
		{'','l'},
		{'','m'},
		{'','n'},
		{'','q'},
		{'','t'},
		{'','w'},
		{'','z'},
		{'','}'},
		{'','~'},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
		{'',''},
	};

	public static final char tableKatakanaDakuonFirst[][]={
		{'',''},
		{'','K'},
		{'','M'},
		{'','O'},
		{'','Q'},
		{'','S'},
		{'','U'},
		{'','W'},
		{'','Y'},
		{'','['},
		{'',']'},
		{'','_'},
		{'','a'},
		{'','d'},
		{'','f'},
		{'','h'},
		{'','o'},
		{'','r'},
		{'','u'},
		{'','x'},
		{'','{'},
	};

	public static final char tableKatakanaDakuonSecond[][]={
		{'','p'},
		{'','s'},
		{'','v'},
		{'','y'},
		{'','|'},
	};

	static final int checkHankakuAscii(Reader reader,int iRead)
		throws IOException
	{
		for(int iLoop2=0;iLoop2<ZenkakuTable.tableAnk.length;iLoop2++)
		{
			if(ZenkakuTable.tableAnk[iLoop2][0]==iRead)
			{
				//if(IS_DEBUG)System.out.println("`FbN:rqbg["+(char)iRead+","+ZenkakuTable.tableAnk[iLoop2][0]+"]");
				return ZenkakuTable.tableAnk[iLoop2][1];
			}
		}
		return -1;
	}

	static final int checkZenkakuAscii(Reader reader,int iRead)
		throws IOException
	{
		for(int iLoop2=0;iLoop2<ZenkakuTable.tableAnk.length;iLoop2++)
		{
			if(ZenkakuTable.tableAnk[iLoop2][1]==iRead)
			{
				return ZenkakuTable.tableAnk[iLoop2][0];
			}
		}
		return -1;
	}

	static final int checkHankakuKatakana(Reader reader,int iRead)
		throws IOException
	{
		for(int iLoop=0;iLoop<ZenkakuTable.tableKatakana.length;iLoop++)
		{
			if(ZenkakuTable.tableKatakana[iLoop][0]==iRead)
			{
				int iDakuon=checkDakuon1(reader,iRead);
				if(iDakuon>=0)
				{
					return iDakuon;
				}

				iDakuon=checkDakuon2(reader,iRead);
				if(iDakuon>=0)
				{
					return iDakuon;
				}
				return ZenkakuTable.tableKatakana[iLoop][1];
			}
		}
		return -1;
	}

	/**
	 * `FbN1
	 */
	private static final int checkDakuon1(Reader reader,int iRead)
		throws IOException
	{
		// `FbN
		reader.mark(1);
		int iNext=reader.read();
		if(iNext<0)
		{
			reader.reset();
			return -1;
		}

		if(iNext=='')
		{
			for(int iLoopDakuon=0;iLoopDakuon<ZenkakuTable.tableKatakanaDakuonFirst.length;iLoopDakuon++)
			{
				if(ZenkakuTable.tableKatakanaDakuonFirst[iLoopDakuon][0]==iRead)
				{
					return ZenkakuTable.tableKatakanaDakuonFirst[iLoopDakuon][1];
				}
			}
		}

		reader.reset();
		return -1;
	}

	/**
	 * `FbN2
	 */
	private static final int checkDakuon2(Reader reader,int iRead)
		throws IOException
	{
		reader.mark(1);
		int iNext=reader.read();
		if(iNext<0)
		{
			reader.reset();
			return -1;
		}

		if(iNext=='')
		{
			for(int iLoopDakuon=0;iLoopDakuon<ZenkakuTable.tableKatakanaDakuonSecond.length;iLoopDakuon++)
			{
				if(ZenkakuTable.tableKatakanaDakuonSecond[iLoopDakuon][0]==iRead)
				{
					return ZenkakuTable.tableKatakanaDakuonSecond[iLoopDakuon][1];
				}
			}
		}

		reader.reset();
		return -1;
	}
}

