/**
 * IgaLib -> String
 * Copyright (C) 2001  Tosiki IGA , IgaLib project member
 *   (http://homepage2.nifty.com/igat/igapyon/index.html)
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jp.ne.nifty.iga.tosiki.string;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import java.io.*;

/**
 * SpϊNXQeXgNXłB
 * JUnit𗘗păeXg{邽߂ɑ݂NXłB<BR>
 * ̃NXg̗prɗp邱Ƃ͖ł傤B
 *
 * @author Tosiki IGA
 */
public class ZenkakuTest
	extends TestCase
{
	public ZenkakuTest(String name)
	{
		super(name);
	}

	public static final void main(String[] args)
	{
		junit.textui.TestRunner.run(ZenkakuTest.class);
	}

	//public void test()
	//{
	//	try{
	//		testZenkakuReader();
	//		testZenkakuUtil();
	//		testKatakanaZenkakuUtil();
	//		testNormalizeZenkakuUtil();
	//	}catch(IOException ex){
	//		ex.printStackTrace();
	//		fail("Ɉُ픭:"+ex.toString());
	//	}
	//}

	public void testZenkakuReader()
		throws IOException
	{
		{
			ZenkakuReader reader=new ZenkakuReader(new StringReader(
				"ABC߶޷޸޹޺ރUWY[]"));
			StringWriter writer=new StringWriter();
			for(;;)
			{
				int iRead=reader.read();
				if(iRead<0)
				{
					break;
				}
				writer.write(iRead);
			}
			reader.close();
			writer.flush();
			writer.close();
			assertEquals(writer.toString(),"ACE`abpsvKMOQSUWY[]");
		}

		zenkakuReaderArrayTest(1,0);
		zenkakuReaderArrayTest(2,0);
		zenkakuReaderArrayTest(4,0);
		zenkakuReaderArrayTest(8,0);
		zenkakuReaderArrayTest(16,0);
		zenkakuReaderArrayTest(21,0);
		zenkakuReaderArrayTest(22,0);
		zenkakuReaderArrayTest(23,0);
		zenkakuReaderArrayTest(32,0);
		zenkakuReaderArrayTest(64,0);

		zenkakuReaderArrayTest(16,3);
	}

	private void zenkakuReaderArrayTest(int iBufSize,int iOffset)
		throws IOException
	{
		ZenkakuReader reader=new ZenkakuReader(new StringReader(
			"ABC߶޷޸޹޺ރUWY[]"));
		StringWriter writer=new StringWriter();
		char[] cszBuf=new char[iBufSize];
		for(;;)
		{
			int iRead=reader.read(cszBuf,iOffset,cszBuf.length-iOffset);
			if(iRead<0)
			{
				break;
			}
			writer.write(cszBuf,iOffset,iRead);
		}
		reader.close();
		writer.flush();
		writer.close();
		assertEquals(writer.toString(),"ACE`abpsvKMOQSUWY[]");
	}

	public void testZenkakuUtil()
	{
		assertEquals(
			ZenkakuUtil.toZenkaku("ABC߶޷޸޹޺ރUWY[]")
			,"ACE`abpsvKMOQSUWY[]");

		assertEquals(
			ZenkakuUtil.toZenkaku(" !\"#$%&'()*+,-./")
			,"@Ihfij{C|D^");
		assertEquals(
			ZenkakuUtil.toZenkaku("0123456789")
			,"OPQRSTUVWX");
		assertEquals(
			ZenkakuUtil.toZenkaku(":;<=>?@")
			,"FGH");
		assertEquals(
			ZenkakuUtil.toZenkaku("ABCDEFGHIJKLMNOPQRSTUVWXYZ")
			,"`abcdefghijklmnopqrstuvwxy");
		assertEquals(
			ZenkakuUtil.toZenkaku("[\\]^_`")
			,"mnOQM");
		assertEquals(
			ZenkakuUtil.toZenkaku("abcdefghijklmnopqrstuvwxyz")
			,"");
		assertEquals(
			ZenkakuUtil.toZenkaku("{|}~")
			,"obp`");
		assertEquals(
			ZenkakuUtil.toZenkaku("")
			,"EBuvAE");
		assertEquals(
			ZenkakuUtil.toZenkaku("")
			,"@BDFHb[ACEGIJLNPRTVXZ\^`cegijklmnqtwz}~");
		assertEquals(
			ZenkakuUtil.toZenkaku("޶޷޸޹޺޻޼޽޾޿")
			,"KMOQSUWY[]_adfhorux{");
		assertEquals(
			ZenkakuUtil.toZenkaku("")
			,"psvy|");

		assertEquals(
			362
			,ZenkakuUtil.toInteger("RUQ"));
		assertEquals(
			0
			,ZenkakuUtil.toInteger(""));
		assertEquals(
			0
			,ZenkakuUtil.toInteger(null));
	}

	public void testKatakanaZenkakuUtil()
	{
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("ABC߶޷޸޹޺ރUWY[]")
			,"ACEABCpsvKMOQSUWY[]");

		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku(" !\"#$%&'()*+,-./")
			," !\"#$%&'()*+,-./");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("0123456789")
			,"0123456789");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku(":;<=>?@")
			,":;<=>?@");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("ABCDEFGHIJKLMNOPQRSTUVWXYZ")
			,"ABCDEFGHIJKLMNOPQRSTUVWXYZ");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("[\\]^_`")
			,"[\\]^_`");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("abcdefghijklmnopqrstuvwxyz")
			,"abcdefghijklmnopqrstuvwxyz");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("{|}~")
			,"{|}~");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("")
			,"EBuvAE");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("")
			,"@BDFHb[ACEGIJLNPRTVXZ\^`cegijklmnqtwz}~");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("޶޷޸޹޺޻޼޽޾޿")
			,"KMOQSUWY[]_adfhorux{");
		assertEquals(
			ZenkakuUtil.toKatakanaZenkaku("")
			,"psvy|");
	}

	public void testNormalizeZenkakuUtil()
	{
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("ABC߶޷޸޹޺ރUWY[]")
			,"ACEabcABCpsvKMOQSUWY[]");

		assertEquals(
			ZenkakuUtil.normalizeZenkaku("@Ihfij{C|D^")
			," !\"#$%&'()*+,-./");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("OPQRSTUVWX")
			,"0123456789");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("FGH")
			,":;<=>?@");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("`abcdefghijklmnopqrstuvwxy")
			,"ABCDEFGHIJKLMNOPQRSTUVWXYZ");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("mnOQM")
			,"[\\]^_`");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("")
			,"abcdefghijklmnopqrstuvwxyz");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("obp`")
			,"{|}~");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("EBuvAE")
			,"EBuvAE");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("")
			,"@BDFHb[ACEGIJLNPRTVXZ\^`cegijklmnqtwz}~");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("@BDFHb[ACEGIJLNPRTVXZ\^`cegijklmnqtwz}~")
			,"@BDFHb[ACEGIJLNPRTVXZ\^`cegijklmnqtwz}~");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("޶޷޸޹޺޻޼޽޾޿")
			,"KMOQSUWY[]_adfhorux{");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("KMOQSUWY[]_adfhorux{")
			,"KMOQSUWY[]_adfhorux{");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("")
			,"psvy|");
		assertEquals(
			ZenkakuUtil.normalizeZenkaku("psvy|")
			,"psvy|");
	}
}


